@@ -16,16 +16,17 @@ use ratatui::widgets::{
 	Block as TuiBlock, Borders, Clear, List, ListItem, Paragraph, Row, Table, Wrap,
 };
 use ratatui::Frame;
+use regex_lite::RegexBuilder;
 use std::fmt::{Debug, Display, Formatter};
 use std::slice::Iter;
 use std::sync::mpsc::Sender;
 use termion::event::Key;
 use unicode_width::UnicodeWidthStr;
 
-/* Table header of the module table */
+/// Table header of the module table
 pub const TABLE_HEADER: &[&str] = &[" Module", "Size", "Used by"];
 
-/* Available options in the module management menu */
+/// Available options in the module management menu
 const OPTIONS: &[(&str, &str)] = &[
 	("unload", "Unload the module"),
 	("reload", "Reload the module"),
@@ -36,7 +37,7 @@ const OPTIONS: &[(&str, &str)] = &[
 	("clear", "Clear the ring buffer"),
 ];
 
-/* Supported directions of scrolling */
+/// Supported directions of scrolling
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum ScrollDirection {
 	Up,
@@ -48,11 +49,7 @@ pub enum ScrollDirection {
 }
 
 impl ScrollDirection {
-	/**
-	 * Return iterator of the available scroll directions.
-	 *
-	 * @return Iter
-	 */
+	/// Return iterator of the available scroll directions.
 	#[allow(dead_code)]
 	pub fn iter() -> Iter<'static, ScrollDirection> {
 		[
@@ -67,8 +64,7 @@ impl ScrollDirection {
 	}
 }
 
-/* Main blocks of the terminal */
-
+/// Main blocks of the terminal
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Sequence)]
 pub enum Block {
 	UserInput,
@@ -77,14 +73,14 @@ pub enum Block {
 	Activities,
 }
 
-/* Sizes of the terminal blocks */
+/// Sizes of the terminal blocks
 pub struct BlockSize {
 	pub input: u16,
 	pub info: u16,
 	pub activities: u16,
 }
 
-/* Default initialization values for BlockSize */
+/// Default initialization values for BlockSize
 impl Default for BlockSize {
 	fn default() -> Self {
 		Self {
@@ -95,7 +91,7 @@ impl Default for BlockSize {
 	}
 }
 
-/* User input mode */
+/// User input mode
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Sequence)]
 pub enum InputMode {
 	None,
@@ -104,17 +100,13 @@ pub enum InputMode {
 }
 
 impl InputMode {
-	/**
-	 * Check if input mode is set.
-	 *
-	 * @return bool
-	 */
+	/// Check if input mode is set.
 	pub fn is_none(self) -> bool {
 		self == Self::None
 	}
 }
 
-/* Implementation of Display for using InputMode members as string */
+/// Implementation of Display for using InputMode members as string
 impl Display for InputMode {
 	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
 		let mut input_mode = *self;
@@ -128,7 +120,7 @@ impl Display for InputMode {
 	}
 }
 
-/* Application settings and related methods  */
+/// Application settings and related methods  
 pub struct App {
 	pub selected_block: Block,
 	pub default_block: Block,
@@ -143,13 +135,7 @@ pub struct App {
 }
 
 impl App {
-	/**
-	 * Create a new app instance.
-	 *
-	 * @param  Block
-	 * @param  Style
-	 * @return App
-	 */
+	/// Create a new app instance.
 	pub fn new(block: Block, style: Style) -> Self {
 		Self {
 			selected_block: block,
@@ -178,7 +164,7 @@ impl App {
 		}
 	}
 
-	/* Reset app properties to default. */
+	/// Reset app properties to default.
 	pub fn refresh(&mut self) {
 		self.selected_block = self.default_block;
 		self.block_size = BlockSize::default();
@@ -189,12 +175,7 @@ impl App {
 		self.show_options = false;
 	}
 
-	/**
-	 * Get style depending on the selected state of the block.
-	 *
-	 * @param  block
-	 * @return TuiStyle
-	 */
+	/// Get style depending on the selected state of the block.
 	pub fn block_style(&self, block: Block) -> TuiStyle {
 		if self.show_options {
 			self.style.colored
@@ -205,11 +186,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Get the size of the selected block.
-	 *
-	 * @return u16
-	 */
+	/// Get the size of the selected block.
 	pub fn block_size(&mut self) -> &mut u16 {
 		match self.selected_block {
 			Block::ModuleInfo => &mut self.block_size.info,
@@ -218,11 +195,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Get clipboard contents as String.
-	 *
-	 * @return contents
-	 */
+	/// Get clipboard contents as String.
 	pub fn get_clipboard_contents(&mut self) -> String {
 		if let Some(clipboard) = self.clipboard.as_mut() {
 			if let Ok(contents) = clipboard.get_contents() {
@@ -232,11 +205,7 @@ impl App {
 		String::new()
 	}
 
-	/**
-	 * Set clipboard contents.
-	 *
-	 * @param contents
-	 */
+	/// Set clipboard contents.
 	pub fn set_clipboard_contents(&mut self, contents: &str) {
 		if let Some(clipboard) = self.clipboard.as_mut() {
 			if let Err(e) = clipboard.set_contents(contents.to_string()) {
@@ -245,11 +214,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Show help message on the information block.
-	 *
-	 * @param kernel_modules
-	 */
+	/// Show help message on the information block.
 	pub fn show_help_message(&mut self, kernel_modules: &mut KernelModules<'_>) {
 		let key_bindings: Vec<(&str, &str)> = util::KEY_BINDINGS.to_vec();
 		let mut help_text = Vec::new();
@@ -275,11 +240,7 @@ impl App {
 			.set(Text::from(help_text), help_text_raw.join("\n"));
 	}
 
-	/**
-	 * Show dependent modules on the information block.
-	 *
-	 * @param kernel_modules
-	 */
+	/// Show dependent modules on the information block.
 	#[allow(clippy::nonminimal_bool)]
 	pub fn show_dependent_modules(
 		&mut self,
@@ -317,13 +278,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Draw a block according to the index.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param kernel
-	 */
+	/// Draw a block according to the index.
 	pub fn draw_dynamic_block(
 		&mut self,
 		frame: &mut Frame,
@@ -342,13 +297,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Draw a paragraph widget for using as user input.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param tx
-	 */
+	/// Draw a paragraph widget for using as user input.
 	pub fn draw_user_input(
 		&self,
 		frame: &mut Frame,
@@ -387,13 +336,7 @@ impl App {
 		);
 	}
 
-	/**
-	 * Draw a paragraph widget for showing the kernel information.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param info
-	 */
+	/// Draw a paragraph widget for showing the kernel information.
 	pub fn draw_kernel_info(&self, frame: &mut Frame, area: Rect, info: &[String]) {
 		frame.render_widget(
 			Paragraph::new(Span::raw(&info[1]))
@@ -402,7 +345,7 @@ impl App {
 						.border_style(self.style.colored)
 						.borders(Borders::ALL)
 						.title(Span::styled(
-							&format!(
+							format!(
 								"{}{}",
 								info[0],
 								self.style.unicode.get(Symbol::Gear)
@@ -417,47 +360,51 @@ impl App {
 		);
 	}
 
-	/**
-	 * Configure and draw kernel modules table.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param kernel_modules
-	 */
+	/// Configure and draw kernel modules table.
 	pub fn draw_kernel_modules(
 		&mut self,
 		frame: &mut Frame,
 		area: Rect,
 		kernel_modules: &mut KernelModules<'_>,
 	) {
-		/* Filter the module list depending on the input query. */
+		// Filter the module list depending on the input query.
 		let mut kernel_module_list = kernel_modules.default_list.clone();
-		if (self.input_mode == InputMode::None
-			|| self.input_mode == InputMode::Search)
-			&& !self.input_query.is_empty()
-		{
-			kernel_module_list.retain(|module| {
-				module[0]
-					.to_lowercase()
-					.contains(&self.input_query.to_lowercase())
-			});
+		match self.input_mode {
+			InputMode::None | InputMode::Search if !self.input_query.is_empty() => {
+				if kernel_modules.args.regex() {
+					if let Ok(regex) = RegexBuilder::new(&self.input_query)
+						.case_insensitive(true)
+						.build()
+					{
+						kernel_module_list
+							.retain(|module| regex.is_match(module[0].trim_start()))
+					}
+				} else {
+					let input_query = &self.input_query.to_lowercase();
+					kernel_module_list.retain(|module| {
+						module[0].to_lowercase().contains(input_query)
+					});
+				}
+			}
+			_ => {}
 		}
-		/* Append '...' if dependent modules exceed the block width. */
+
+		// Append '...' if dependent modules exceed the block width.
 		let dependent_width = (area.width / 2).saturating_sub(7) as usize;
 		for module in &mut kernel_module_list {
 			if module[2].len() > dependent_width {
 				module[2].truncate(dependent_width);
-				module[2] = format!("{}...", module[2]);
+				module[2].push_str("...");
 			}
 		}
 		kernel_modules.list = kernel_module_list;
-		/* Set the scroll offset for modules. */
+		// Set the scroll offset for modules.
 		let modules_scroll_offset = area
 			.height
 			.checked_sub(5)
 			.and_then(|height| kernel_modules.index.checked_sub(height as usize))
 			.unwrap_or(0);
-		/* Set selected state of the modules and render the table widget. */
+		// Set selected state of the modules and render the table widget.
 		frame.render_widget(
 			Table::new(
 				kernel_modules
@@ -504,7 +451,8 @@ impl App {
 							self.style.unicode.get(Symbol::LeftBracket),
 							if !kernel_modules.list.is_empty() {
 								((kernel_modules.index + 1) as f64
-									/ kernel_modules.list.len() as f64 * 100.0) as u64
+									/ kernel_modules.list.len() as f64
+									* 100.0) as u64
 							} else {
 								0
 							},
@@ -520,12 +468,7 @@ impl App {
 		}
 	}
 
-	/**
-	 * Draws the options menu as a popup.
-	 *
-	 * @param frame
-	 * @param area
-	 */
+	/// Draws the options menu as a popup.
 	pub fn draw_options_menu(
 		&mut self,
 		frame: &mut Frame,
@@ -603,13 +546,7 @@ impl App {
 		);
 	}
 
-	/**
-	 * Draw a paragraph widget for showing module information.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param kernel_modules
-	 */
+	/// Draw a paragraph widget for showing module information.
 	pub fn draw_module_info(
 		&self,
 		frame: &mut Frame,
@@ -651,13 +588,7 @@ impl App {
 		);
 	}
 
-	/**
-	 * Draw a paragraph widget for showing kernel activities.
-	 *
-	 * @param frame
-	 * @param area
-	 * @param kernel_logs
-	 */
+	/// Draw a paragraph widget for showing kernel activities.
 	pub fn draw_kernel_activities(
 		&self,
 		frame: &mut Frame,
